﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2018 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion
using System;
using System.Collections.Generic;
using System.Linq;
using HeuristicLab.Data;

namespace HeuristicLab.Problems.TestFunctions.MultiObjective {
  internal static class Utilities {
    internal static DoubleMatrix ToMatrix(IEnumerable<double[]> source) {
      try {
        var firstDimension = source.Count();
        var secondDimension = source.GroupBy(row => row.Length).Single().Key; // throws InvalidOperationException if source is not rectangular

        var result = new DoubleMatrix(firstDimension, secondDimension);
        var enumarator = source.GetEnumerator();
        for (var i = 0; i < firstDimension && enumarator.MoveNext(); ++i)
          for (var j = 0; j < secondDimension; ++j)
            result[i, j] = enumarator.Current[j];
        return result;
      }
      catch (InvalidOperationException) {
        throw new InvalidOperationException("The given jagged array is not rectangular.");
      }
    }

    
  }
}
